pressure_level_variables = [
    {
        "name": "divergence",
        "description": "Horizontal divergence of wind field. Unit: 1/s",
    },
    {
        "name": "fraction_of_cloud_cover",
        "description": "Proportion of sky covered by cloud at pressure level. Unit: 0–1 (dimensionless)",
    },
    {
        "name": "geopotential",
        "description": "Gravitational potential energy per unit mass at pressure level. Unit: m²/s²",
    },
    {
        "name": "ozone_mass_mixing_ratio",
        "description": "Ozone mass per unit air mass. Unit: kg/kg",
    },
    {
        "name": "potential_vorticity",
        "description": "Atmospheric potential vorticity. Unit: K·m²/kg/s",
    },
    {
        "name": "relative_humidity",
        "description": "Relative humidity at pressure level. Unit: %",
    },
    {
        "name": "specific_cloud_ice_water_content",
        "description": "Mass of cloud ice per unit mass of moist air. Unit: kg/kg",
    },
    {
        "name": "specific_cloud_liquid_water_content",
        "description": "Mass of cloud liquid water per unit mass of moist air. Unit: kg/kg",
    },
    {
        "name": "specific_humidity",
        "description": "Water vapor mass per unit mass of moist air. Unit: kg/kg",
    },
    {
        "name": "specific_rain_water_content",
        "description": "Rain water mass per unit mass of moist air. Unit: kg/kg",
    },
    {
        "name": "specific_snow_water_content",
        "description": "Snow water mass per unit mass of moist air. Unit: kg/kg",
    },
    {
        "name": "temperature",
        "description": "Air temperature at pressure level. Unit: K",
    },
    {
        "name": "u_component_of_wind",
        "description": "Zonal (east–west) wind component. Unit: m/s",
    },
    {
        "name": "v_component_of_wind",
        "description": "Meridional (north–south) wind component. Unit: m/s",
    },
    {
        "name": "vertical_velocity",
        "description": "Vertical velocity in pressure coordinates. Unit: Pa/s",
    },
    {
        "name": "vorticity",
        "description": "Atmospheric vorticity (tendency of rotation). Unit: 1/s",
    },
]
